@@ -91,7 +91,7 @@ impl AstStyle {
             // Layout System
             ["aspect", rest @ ..] => TailwindAspect::parse(rest, arbitrary)?.boxed(),
             ["container"] => TailwindContainer {}.boxed(),
-            ["columns", rest @ ..] => TailwindColumns::parse(rest)?.boxed(),
+            ["columns", rest @ ..] => TailwindColumns::parse(rest, arbitrary)?.boxed(),
             ["break", rest @ ..] => Self::break_adaptor(rest, arbitrary)?,
             ["box", rest @ ..] => Self::box_adaptor(rest, arbitrary)?,
             // begin https://tailwindcss.com/docs/display
@@ -110,8 +110,8 @@ impl AstStyle {
             // list catched
             ["hidden"] => TailwindDisplay::InlineFlex.boxed(),
             // https://tailwindcss.com/docs/float
-            ["float", rest @ ..] => Self::float_adaptor(rest, arbitrary)?,
-            ["clear", rest @ ..] => TailwindClear::parse(rest)?.boxed(),
+            ["float", rest @ ..] => TailwindFloat::parse(rest, arbitrary)?.boxed(),
+            ["clear", rest @ ..] => TailwindClear::parse(rest, arbitrary)?.boxed(),
             ["isolate"] => TailwindIsolation::Isolate.boxed(),
             ["isolation", "auto"] => TailwindIsolation::Auto.boxed(),
             ["object", rest @ ..] => Self::object_adaptor(rest, arbitrary)?,
@@ -290,11 +290,11 @@ impl AstStyle {
             ["words"] => TailwindBreak::Words.boxed(),
             ["all"] => TailwindBreak::All.boxed(),
             // https://tailwindcss.com/docs/break-before
-            ["before", rest @ ..] => TailwindLayoutBreak::parse_before(rest)?.boxed(),
+            ["before", rest @ ..] => TailwindBreakLayout::parse_before(rest)?.boxed(),
             // https://tailwindcss.com/docs/break-inside
-            ["inside", rest @ ..] => TailwindLayoutBreak::parse_inside(rest)?.boxed(),
+            ["inside", rest @ ..] => TailwindBreakLayout::parse_inside(rest)?.boxed(),
             // https://tailwindcss.com/docs/break-after
-            ["after", rest @ ..] => TailwindLayoutBreak::parse_after(rest)?.boxed(),
+            ["after", rest @ ..] => TailwindBreakLayout::parse_after(rest)?.boxed(),
             _ => return syntax_error!("Unknown break instructions: {}", str.join("-")),
         };
         Ok(out)
@@ -386,8 +386,8 @@ impl AstStyle {
     #[inline]
     fn box_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            ["decoration", "clone"] => TailwindBoxDecorationBreak::Clone.boxed(),
-            ["decoration", "slice"] => TailwindBoxDecorationBreak::Clone.boxed(),
+            ["decoration", "clone"] => TailwindBoxDecoration::Clone.boxed(),
+            ["decoration", "slice"] => TailwindBoxDecoration::Slice.boxed(),
             ["border"] => TailwindBoxSizing::Border.boxed(),
             ["content"] => TailwindBoxSizing::Content.boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
@@ -411,9 +411,9 @@ impl AstStyle {
             ["wrap", "reverse"] => TailwindFlexWrap::WrapReverse.boxed(),
             ["nowrap"] => TailwindFlexWrap::NoWrap.boxed(),
             // https://tailwindcss.com/docs/flex
-            ["auto"] => TailwindBoxDecorationBreak::Clone.boxed(),
-            ["initial"] => TailwindBoxDecorationBreak::Clone.boxed(),
-            ["none"] => TailwindBoxDecorationBreak::Clone.boxed(),
+            ["auto"] => TailwindFlex::Inherit.boxed(),
+            ["initial"] => TailwindFlex::Inherit.boxed(),
+            ["none"] => TailwindFlex::None.boxed(),
             [n] => TailwindFlex::parse(n)?.boxed(),
             _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
         };
@@ -476,29 +476,18 @@ impl AstStyle {
     #[inline]
     fn table_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
-            // https://tailwindcss.com/docs/display#table
-            [] => TailwindDisplay::Table.boxed(),
-            ["caption"] => TailwindFloat::Left.boxed(),
-            ["right"] => TailwindFloat::Right.boxed(),
-            ["none"] => TailwindFloat::None.boxed(),
+            ["caption"] => TailwindTableLayout::Auto.boxed(),
+            ["right"] => TailwindTableLayout::Auto.boxed(),
+            ["none"] => TailwindTableLayout::Auto.boxed(),
             // https://tailwindcss.com/docs/table-layout
             ["auto"] => TailwindTableLayout::Auto.boxed(),
             ["fixed"] => TailwindTableLayout::Fixed.boxed(),
+            // https://tailwindcss.com/docs/display#table
+            [] => TailwindDisplay::Table.boxed(),
             _ => return syntax_error!("Unknown table instructions: {}", str.join("-")),
         };
         Ok(out)
     }
-    #[inline]
-    fn float_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/float
-            ["left"] => TailwindFloat::Left.boxed(),
-            ["right"] => TailwindFloat::Right.boxed(),
-            ["none"] => TailwindFloat::None.boxed(),
-            _ => return syntax_error!("Unknown float instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
 
     #[inline]
     fn object_adaptor(str: &[&str], arbitrary: &str) -> Result<Box<dyn TailwindInstance>> {
@@ -528,9 +517,9 @@ impl AstStyle {
     fn overflow_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/overflow
-            ["x", pattern @ ..] => TailwindOverflow::parse_x(pattern)?.boxed(),
-            ["y", pattern @ ..] => TailwindOverflow::parse_y(pattern)?.boxed(),
-            _ => TailwindOverflow::parse_xy(str)?.boxed(),
+            ["x", pattern @ ..] => TailwindOverflow::parse(pattern, Some(true))?.boxed(),
+            ["y", pattern @ ..] => TailwindOverflow::parse(pattern, Some(false))?.boxed(),
+            _ => TailwindOverflow::parse(str, None)?.boxed(),
         };
         Ok(out)
     }
@@ -538,9 +527,9 @@ impl AstStyle {
     fn overscroll_adaptor(str: &[&str], _: &str) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/overscroll-behavior
-            ["x", pattern @ ..] => TailwindOverscroll::parse_x(pattern)?.boxed(),
-            ["y", pattern @ ..] => TailwindOverscroll::parse_y(pattern)?.boxed(),
-            _ => TailwindOverscroll::parse_xy(str)?.boxed(),
+            ["x", pattern @ ..] => TailwindOverscroll::parse(pattern, Some(true))?.boxed(),
+            ["y", pattern @ ..] => TailwindOverscroll::parse(pattern, Some(true))?.boxed(),
+            _ => TailwindOverscroll::parse(str, None)?.boxed(),
         };
         Ok(out)
     }
