@@ -1,28 +1,25 @@
 use super::*;
 
+impl Display for AspectKind {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Auto => write!(f, "auto"),
+            Self::Radio(a, b) => write!(f, "{}/{}", a, b),
+            Self::Global(g) => write!(f, "{}", g),
+        }
+    }
+}
+
 impl Display for TailwindAspect {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match self {
-            Self::Auto => {
-                write!(f, "aspect-auto")
-            }
-            Self::Arbitrary(a, b) => {
-                write!(f, "aspect-{}/{}", a, b)
-            }
-        }
+        write!(f, "aspect-{}", self.kind)
     }
 }
 
 impl TailwindInstance for TailwindAspect {
     fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        let ar = match self {
-            Self::Auto => "auto",
-            Self::Arbitrary(_, _) => {
-                todo!()
-            }
-        };
         css_attributes! {
-            "aspect-ratio" => ar
+            "aspect-ratio" => self.kind
         }
     }
 }
@@ -35,7 +32,7 @@ impl Display for TailwindContainer {
 
 impl TailwindInstance for TailwindContainer {}
 
-impl Display for LayoutBreakKind {
+impl Display for BreakKind {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Before => f.write_str("break-before"),
@@ -45,13 +42,13 @@ impl Display for LayoutBreakKind {
     }
 }
 
-impl Display for TailwindLayoutBreak {
+impl Display for TailwindBreakLayout {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "{}-{}", self.kind, self.info)
     }
 }
 
-impl TailwindInstance for TailwindLayoutBreak {
+impl TailwindInstance for TailwindBreakLayout {
     fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
         let class = self.kind.to_string();
         let breaking = self.info.to_string();
@@ -61,37 +58,82 @@ impl TailwindInstance for TailwindLayoutBreak {
     }
 }
 
+impl Display for ColumnKind {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Auto => write!(f, "auto"),
+            Self::Columns(n) => write!(f, "{}", n),
+            Self::Length(n) => write!(f, "{}", n),
+        }
+    }
+}
+
 impl Display for TailwindColumns {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        write!(f, "columns-{}", self.kind)
     }
 }
 
 impl TailwindInstance for TailwindColumns {
-    fn id(&self) -> String {
-        todo!()
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        let columns = match self.kind {
+            ColumnKind::Auto => "auto".to_string(),
+            ColumnKind::Columns(n) => format!("{}", n),
+            ColumnKind::Length(n) => format!("{:?}", n),
+        };
+        css_attributes! {
+            "columns" => columns
+        }
     }
 }
 
-impl Display for TailwindBoxDecorationBreak {
+impl Display for BoxDecoration {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        match self {
+            Self::Clone => f.write_str("clone"),
+            Self::Slice => f.write_str("slice"),
+        }
     }
 }
 
-impl TailwindInstance for TailwindBoxDecorationBreak {
-    fn id(&self) -> String {
-        todo!()
+impl Display for TailwindBoxDecoration {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "box-decoration-{}", self.kind)
+    }
+}
+
+impl TailwindInstance for TailwindBoxDecoration {
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        let decoration = self.kind.to_string();
+        css_attributes! {
+            "box-decoration-break" => decoration
+        }
+    }
+}
+
+impl Display for BoxSizing {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Border => f.write_str("border"),
+            Self::Content => f.write_str("content"),
+        }
     }
 }
 
 impl Display for TailwindBoxSizing {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        write!(f, "box-{}", self.kind)
     }
 }
 
-impl TailwindInstance for TailwindBoxSizing {}
+impl TailwindInstance for TailwindBoxSizing {
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        let size = format!("{}-box", self.kind);
+        css_attributes! {
+            "box-sizing" => size
+        }
+    }
+}
 
 impl Display for TailwindDisplay {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
@@ -101,13 +143,30 @@ impl Display for TailwindDisplay {
 
 impl TailwindInstance for TailwindDisplay {}
 
-impl Display for TailwindClear {
+impl Display for ClearKind {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        match self {
+            Self::Left => f.write_str("left"),
+            Self::Right => f.write_str("right"),
+            Self::Both => f.write_str("both"),
+            Self::None => f.write_str("none"),
+        }
     }
 }
 
-impl TailwindInstance for TailwindClear {}
+impl Display for TailwindClear {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "clear-{}", self.kind)
+    }
+}
+
+impl TailwindInstance for TailwindClear {
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        css_attributes! {
+            "clear" => self.kind
+        }
+    }
+}
 
 impl Display for TailwindIsolation {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
